; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.

;-| Super Motions |--------------------------------------------------------
[Command]
name = "upper_pp"
command = ~F, D, DF, x+y

[Command]
name = "upper_pp"
command = ~F, D, DF, y+z

[Command]
name = "upper_pp"
command = ~F, D, DF, x+z
 
[Command]
name = "QCF_pp"
command = ~D, F, x+y

[Command]
name = "QCF_pp"
command = ~D, F, y+z

[Command]
name = "QCF_pp"
command = ~D, F, x+z

[Command]
name = "QCB_pp"
command = ~D, B, x+y

[Command]
name = "QCB_pp"
command = ~D, B, y+z

[Command]
name = "QCF_kk"
command = ~D, F, a+b

[Command]
name = "QCF_kk"
command = ~D, F, b+c

[Command]
name = "QCF_kk"
command = ~D, F, a+c

[Command]
name = "QCB_kk"
command = ~D, B, a+b

[Command]
name = "QCB_kk"
command = ~D, B, b+c

[Command]
name = "QCB_kk"
command = ~D, B, a+c

;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_z"
command = ~F, D, DF, z

[Command]
name = "QCF_k1"
command = ~D, F, a

[Command]
name = "QCF_k2"
command = ~D, F, b

[Command]
name = "QCF_k3"
command = ~D, F, c

[Command]
name = "QCB_k1"
command = ~D, B, a

[Command]
name = "QCB_k2"
command = ~D, B, b

[Command]
name = "QCB_k3"
command = ~D, B, c

[Command]
name = "QCF_p1"
command = ~D, F, x

[Command]
name = "QCF_p2"
command = ~D, F, y

[Command]
name = "QCF_p3"
command = ~D, F, z

[Command]
name = "QCB_p1"
command = ~D, B, x

[Command]
name = "QCB_p2"
command = ~D, B, y

[Command]
name = "QCB_p3"
command = ~D, B, z

[Command]
name = "QCF_p"
command = ~D, F, x

[Command]
name = "QCF_p"
command = ~D, F, y

[Command]
name = "QCF_p"
command = ~D, F, z

[Command]
name = "roll"
command = ~B, D, x

[Command]
name = "roll"
command = ~B, D, y

[Command]
name = "roll"
command = ~B, D, z

[Command]
name = "roll"
command = ~B, D, a

[Command]
name = "roll"
command = ~B, D, b

[Command]
name = "roll"
command = ~B, D, c

[Command]
name = "counter"
command = ~B, D, c

[Command]
name = "Super_Jump"
command = $D, $U

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "hold_a"
command = /$a
time = 1

[Command]
name = "hold_b"
command = /$b
time = 1

[Command]
name = "hold_c"
command = /$c
time = 1

[Command]
name = "hold_x"
command = /$x
time = 1

[Command]
name = "hold_y"
command = /$y
time = 1

[Command]
name = "hold_z"
command = /$z
time = 1

[Command]
name = "release_z"
command = ~z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown"
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Multi-Dash Attack Hyper
[State -1, MultiAttackHyper]
type = ChangeState
value = 1050
triggerall = command = "QCB_pp" && command != "holddown" && power >= 1000
trigger1 = ctrl &&  statetype != A
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 205 && MoveContact
trigger4 = stateno = 215 && MoveContact
trigger5 = stateno = 220 && MoveContact
trigger6 = stateno = 225 && MoveContact
trigger7 = stateno = 300 && MoveContact
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 315 && MoveContact
trigger10 = stateno = 320 && MoveContact
trigger11 = stateno = 325 && MoveContact
trigger12 = stateno = 400 && MoveContact
trigger13 = stateno = 405 && MoveContact
trigger14 = stateno = 415 && MoveContact
trigger15 = stateno = 420 && MoveContact
trigger16 = stateno = 411 && MoveContact
;---------------------------------------------------------------------------
;Dragon Flame attack state
;If var(49) (the timer var) is above 0 then his scissor snip attack is active
;Let this be the first statedef in your command file to ensure that it get's checked before all the other's
[State -1, DragonFlameAttackState]
type = ChangeState
value = 1036
triggerall = var(49) > 0 && ctrl
;triggerall = MoveContact = var(50)
trigger1 = command = "x"
trigger2 = command = "y"
trigger3 = command = "z"
trigger4 = command = "a"
trigger5 = command = "b"
trigger6 = command = "c"

;To insure that no other attack happens while the Dragon Flame hyper is activated
;we must add this statement to the triggerall portion of every attack

;triggerall = var(49) <= 0

;If our timer variable = 0 or is below zero the scissor snip hyper is no longer active
;---------------------------------------------------------------------------
;Giant Spinning Buzzsaw Hyper
[State -1, RD]
type = ChangeState
value = 1040
triggerall = command = "QCF_kk" && command != "holddown" && power >= 1000
trigger1 = ctrl &&  statetype != A
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 205 && MoveContact
trigger4 = stateno = 215 && MoveContact
trigger5 = stateno = 220 && MoveContact
trigger6 = stateno = 225 && MoveContact
trigger7 = stateno = 300 && MoveContact
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 315 && MoveContact
trigger10 = stateno = 320 && MoveContact
trigger11 = stateno = 325 && MoveContact
;---------------------------------------------------------------------------
;Super Dragon Hyper
[State -1, BP]
type = ChangeState
value = 1030
triggerall = command = "QCB_kk" && command != "holddown" && power >= 3000
trigger1 = ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 205 && MoveContact
trigger4 = stateno = 215 && MoveContact
trigger5 = stateno = 220 && MoveContact
trigger6 = stateno = 225 && MoveContact
trigger7 = stateno = 300 && MoveContact
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 315 && MoveContact
trigger10 = stateno = 320 && MoveContact
trigger11 = stateno = 325 && MoveContact
trigger12 = stateno = 400 && MoveContact
trigger13 = stateno = 405 && MoveContact
trigger14 = stateno = 415 && MoveContact
trigger15 = stateno = 420 && MoveContact
trigger16 = stateno = 411 && MoveContact
;---------------------------------------------------------------------------
;Buzzsaw Barrage Hyper (Stand)
[State -1, HM]
type = ChangeState
value = 1000
triggerall = command = "QCF_pp" && command != "holddown" && power >= 1000
trigger1 = ctrl &&  statetype != A
trigger2 = stateno = 200 && MoveContact ;Light Punch
trigger3 = stateno = 205 && MoveContact ;Medium Punch
trigger4 = stateno = 210 && MoveContact ;Hard Punch
trigger5 = stateno = 211 && MoveContact
trigger6 = stateno = 213 && MoveContact
trigger7 = stateno = 214 && MoveContact
trigger8 = stateno = 215 && MoveContact
trigger9 = stateno = 220 && MoveContact
trigger10 = stateno = 225 && MoveContact
trigger11 = stateno = 300 && MoveContact
trigger12 = stateno = 305 && MoveContact
trigger13 = stateno = 310 && MoveContact
trigger14 = stateno = 315 && MoveContact
trigger15 = stateno = 320 && MoveContact
trigger16 = stateno = 325 && MoveContact
;---------------------------------------------------------------------------
;Buzzsaw Barrage Hyper (Air)
[State -1, HM]
type = ChangeState
value = 1001
triggerall = command = "QCF_pp" && command != "holddown" && power >= 1000
trigger1 = ctrl &&  statetype = A
trigger2 = stateno = 400 && MoveContact
trigger3 = stateno = 405 && MoveContact
trigger4 = stateno = 410 && MoveContact
trigger5 = stateno = 411 && MoveContact
trigger6 = stateno = 415 && MoveContact
trigger7 = stateno = 420 && MoveContact
trigger8 = stateno = 425 && MoveContact
;---------------------------------------------------------------------------
;Standing Light Buzzsaw Uppercut
[State -1, SMUW]
type = ChangeState
value = 550
triggerall = command = "upper_x" && command != "holddown"
triggerall = stateno != 1030
triggerall = stateno != 1031
trigger1 = statetype != A && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 205 && MoveContact
trigger4 = stateno = 215 && MoveContact
trigger5 = stateno = 220 && MoveContact
trigger6 = stateno = 225 && MoveContact
trigger7 = stateno = 300 && MoveContact
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 315 && MoveContact
trigger10 = stateno = 320 && MoveContact
trigger11 = stateno = 325 && MoveContact
;---------------------------------------------------------------------------
;Standing Medium Buzzsaw Uppercut
[State -1, SMUM]
type = ChangeState
value = 553
triggerall = command = "upper_y" && command != "holddown"
triggerall = stateno != 1030
triggerall = stateno != 1031
trigger1 = statetype != A && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 205 && MoveContact
trigger4 = stateno = 215 && MoveContact
trigger5 = stateno = 220 && MoveContact
trigger6 = stateno = 225 && MoveContact
trigger7 = stateno = 300 && MoveContact
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 315 && MoveContact
trigger10 = stateno = 320 && MoveContact
trigger11 = stateno = 325 && MoveContact
;---------------------------------------------------------------------------
;Standing Hard Buzzsaw Uppercut
[State -1, SMUH]
type = ChangeState
value = 555
triggerall = command = "upper_z" && command != "holddown"
triggerall = stateno != 1030
triggerall = stateno != 1031
trigger1 = statetype != A && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 205 && MoveContact
trigger4 = stateno = 215 && MoveContact
trigger5 = stateno = 220 && MoveContact
trigger6 = stateno = 225 && MoveContact
trigger7 = stateno = 300 && MoveContact
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 315 && MoveContact
trigger10 = stateno = 320 && MoveContact
trigger11 = stateno = 325 && MoveContact
;---------------------------------------------------------------------------
;Jumping Light Buzzsaw Uppercut
[State -1, SMUW]
type = ChangeState
value = 560
triggerall = command = "upper_x" && command != "holddown"
triggerall = stateno != 1030
triggerall = stateno != 1031
trigger1 = statetype = A && ctrl
trigger2 = stateno = 400 && MoveContact
trigger3 = stateno = 405 && MoveContact
trigger4 = stateno = 415 && MoveContact
trigger5 = stateno = 420 && MoveContact
;---------------------------------------------------------------------------
;Jumping Medium Buzzsaw Uppercut
[State -1, JMUM]
type = ChangeState
value = 561
triggerall = command = "upper_y" && command != "holddown"
triggerall = stateno != 1030
triggerall = stateno != 1031
trigger1 = statetype = A && ctrl
trigger2 = stateno = 400 && MoveContact
trigger3 = stateno = 405 && MoveContact
trigger4 = stateno = 415 && MoveContact
trigger5 = stateno = 420 && MoveContact
;---------------------------------------------------------------------------
;Jumping Hard Buzzsaw Uppercut
[State -1, JMUH]
type = ChangeState
value = 562
triggerall = command = "upper_z" && command != "holddown"
triggerall = stateno != 1030
triggerall = stateno != 1031
trigger1 = statetype = A && ctrl
trigger2 = stateno = 400 && MoveContact
trigger3 = stateno = 405 && MoveContact
trigger4 = stateno = 415 && MoveContact
trigger5 = stateno = 420 && MoveContact
;---------------------------------------------------------------------------
;Light Buzzsaw Throw
[State -1, JTH]
type = ChangeState
value = 500
triggerall = command = "QCF_p1" && command != "holddown" && var(4) = 0
triggerall = numhelper(500)= 0
trigger1 = statetype = S && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 205 && MoveContact
trigger4 = stateno = 215 && MoveContact
trigger5 = stateno = 220 && MoveContact
trigger6 = stateno = 225 && MoveContact
trigger7 = stateno = 300 && MoveContact
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 315 && MoveContact
trigger10 = stateno = 320 && MoveContact
trigger11 = stateno = 325 && MoveContact
;---------------------------------------------------------------------------
;Medium Buzzsaw Throw
[State -1, STH]
type = ChangeState
value = 501
triggerall = command = "QCF_p2" && command != "holddown" && var(4) = 0
triggerall = numhelper(500)= 0
trigger1 = statetype = S && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 205 && MoveContact
trigger4 = stateno = 215 && MoveContact
trigger5 = stateno = 220 && MoveContact
trigger6 = stateno = 225 && MoveContact
trigger7 = stateno = 300 && MoveContact
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 315 && MoveContact
trigger10 = stateno = 320 && MoveContact
trigger11 = stateno = 325 && MoveContact
;---------------------------------------------------------------------------
;Hard Buzzsaw Throw
[State -1, FTH]
type = ChangeState
value = 502
triggerall = command = "QCF_p3" && command != "holddown" && var(4) = 0
triggerall = numhelper(500)= 0
trigger1 = statetype = S && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 205 && MoveContact
trigger4 = stateno = 215 && MoveContact
trigger5 = stateno = 220 && MoveContact
trigger6 = stateno = 225 && MoveContact
trigger7 = stateno = 300 && MoveContact
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 315 && MoveContact
trigger10 = stateno = 320 && MoveContact
trigger11 = stateno = 325 && MoveContact
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF" && statetype = S && ctrl && stateno != [100,105]
;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB" && statetype = S && ctrl && stateno != [100,107]
;---------------------------------------------------------------------------
;Throw
[State -1, T]
type = ChangeState
value = 249
triggerall = command = "z" && statetype = S && ctrl && stateno != 100
trigger1 = command = "holdfwd" && p2bodydist X < 7 && p2movetype != H
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger2 = command = "holdback" && p2bodydist X < 10 && p2movetype != H
trigger2 = (p2statetype = S) || (p2statetype = C)
;---------------------------------------------------------------------------
;Throw
[State -1, T]
type = ChangeState
value = 249
triggerall = command = "y" && statetype = S && ctrl && stateno != 100
trigger1 = command = "holdfwd" && p2bodydist X < 7 && p2movetype != H
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger2 = command = "holdback" && p2bodydist X < 10 && p2movetype != H
trigger2 = (p2statetype = S) || (p2statetype = C)
;---------------------------------------------------------------------------
;Call Crashman Striker...Help
;[State -1, VA]
type = ChangeState
value = 1700
triggerall = command = "y" && command = "b" && ctrl && numhelper(1700) = 0
trigger1 = statetype = S || statetype = C
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 205 && MoveContact
trigger4 = stateno = 215 && MoveContact
trigger5 = stateno = 220 && MoveContact
trigger6 = stateno = 225 && MoveContact
trigger7 = stateno = 300 && MoveContact
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 315 && MoveContact
trigger10 = stateno = 320 && MoveContact
trigger11 = stateno = 325 && MoveContact
;---------------------------------------------------------------------------
;Standing Light Punch
[State -1, Standing Light Punch]
type = ChangeState
value = 200
triggerall = command = "x" && command != "holddown"
trigger1 = statetype = S && ctrl
trigger2 = stateno = 100
;---------------------------------------------------------------------------
;Standing Medium Punch
[State -1, Standing Medium Punch]
type = ChangeState
value = 205
triggerall = command = "y" && command != "holddown"
trigger1 = statetype = S && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 215 && MoveContact
trigger4 = stateno = 300 && MoveContact
trigger5 = stateno = 315 && MoveContact
trigger6 = stateno = 100
;---------------------------------------------------------------------------
;Dash Back Throw
[State -1, Dash Back Throw]
type = ChangeState
value = 213
triggerall = command = "back_c"
triggerall = numhelper(100)= 0
trigger1 = statetype = S && ctrl
trigger2 = stateno = 105
;---------------------------------------------------------------------------
;Double Blade Throw
[State -1, Double Blade Throw]
type = ChangeState
value = 214
triggerall = command = "QCB_p3" && command != "holddown"
triggerall = numhelper(101)= 0
trigger1 = statetype = S && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 215 && MoveContact
trigger4 = stateno = 300 && MoveContact
trigger5 = stateno = 315 && MoveContact
trigger6 = stateno = 205 && MoveContact
trigger7 = stateno = 220 && MoveContact
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 320 && MoveContact
trigger10 = stateno = 100
;---------------------------------------------------------------------------
;Standing Regular Hard Punch (Blade Throw)
[State -1, Standing Regular Hard Punch]
type = ChangeState
value = 210
triggerall = command = "z" && command != "holddown"
triggerall = numhelper(104)= 0
trigger1 = statetype = S && ctrl
trigger2 = stateno = 200 && MoveContact 
trigger3 = stateno = 215 && MoveContact
trigger4 = stateno = 300 && MoveContact 
trigger5 = stateno = 315 && MoveContact
trigger6 = stateno = 205 && MoveContact
trigger7 = stateno = 220 && MoveContact 
trigger8 = stateno = 305 && MoveContact 
trigger9 = stateno = 320 && MoveContact 
trigger10 = stateno = 100
;---------------------------------------------------------------------------
;Buzzsaw Curve Throw
[State -1, Stand Fierce Punch]
type = ChangeState
value = 211
triggerall = command = "QCF_k3" && command != "holddown"
triggerall = numhelper(102)= 0
trigger1 = statetype = S && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 215 && MoveContact
trigger4 = stateno = 300 && MoveContact
trigger5 = stateno = 315 && MoveContact
trigger6 = stateno = 205 && MoveContact
trigger7 = stateno = 220 && MoveContact
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 320 && MoveContact
trigger10 = stateno = 100
;---------------------------------------------------------------------------
;Standing Light Kick
[State -1, Standing Light Kick]
type = ChangeState
value = 215
triggerall = command = "a" && command != "holddown"
trigger1 = statetype = S && ctrl
trigger2 = stateno = 100
trigger3 = stateno = 200 && MoveContact
;---------------------------------------------------------------------------
;Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 220
triggerall = command = "b" && command != "holddown"
trigger1 = statetype = S && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 215 && MoveContact
trigger4 = stateno = 300 && MoveContact
trigger5 = stateno = 315 && MoveContact
trigger6 = stateno = 100
trigger7 = stateno = 205 && MoveContact
;---------------------------------------------------------------------------
;Standing Hard Kick
[State -1, Standing Hard Kick]
type = ChangeState
value = 225
triggerall = command = "c" && command != "holddown"
trigger1 = statetype = S && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 215 && MoveContact
trigger4 = stateno = 300 && MoveContact
trigger5 = stateno = 315 && MoveContact
trigger6 = stateno = 205 && MoveContact
trigger7 = stateno = 220 && MoveContact
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 320 && MoveContact
trigger10 = stateno = 100
;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A && ctrl
;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 300
triggerall = command = "x" && command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = stateno = 100
;---------------------------------------------------------------------------
;Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 305
triggerall = command = "y" && command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 215 && MoveContact
trigger4 = stateno = 300 && MoveContact
trigger5 = stateno = 315 && MoveContact
;---------------------------------------------------------------------------
;Crouching Hard Punch
[State -1, Crouching Hard Punch]
type = ChangeState
value = 310
triggerall = command = "z" && command = "holddown"
triggerall = numhelper(103)= 0
trigger1 = statetype = C && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 215 && MoveContact 
trigger4 = stateno = 300 && MoveContact
trigger5 = stateno = 315 && MoveContact 
trigger6 = stateno = 205 && MoveContact 
trigger7 = stateno = 220 && MoveContact 
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 320 && MoveContact 
trigger10 = stateno = 100
;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 315
triggerall = command = "a" && command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = stateno = 100
;---------------------------------------------------------------------------
;Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 320
triggerall = command = "b" && command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 215 && MoveContact
trigger4 = stateno = 300 && MoveContact
trigger5 = stateno = 315 && MoveContact
trigger6 = stateno = 100
;---------------------------------------------------------------------------
;Crouching Hard Kick
[State -1, Crouching Hard Kick]
type = ChangeState
value = 325
triggerall = command = "c" && command = "holddown"
trigger1 = statetype = C && ctrl
trigger2 = stateno = 200 && MoveContact
trigger3 = stateno = 215 && MoveContact
trigger4 = stateno = 300 && MoveContact
trigger5 = stateno = 315 && MoveContact
trigger6 = stateno = 205 && MoveContact
trigger7 = stateno = 220 && MoveContact
trigger8 = stateno = 305 && MoveContact
trigger9 = stateno = 320 && MoveContact
;---------------------------------------------------------------------------
;Jumping Light Punch
[State -1, Jumping Light Punch]
type = ChangeState
value = 400
triggerall = command = "x" && command != "holddown"
trigger1 = statetype = A  && ctrl
;---------------------------------------------------------------------------
;Jumping Medium Punch
[State -1, Jumping Medium Punch]
type = ChangeState
value = 405
triggerall = command = "y" && command != "holddown"
trigger1 = statetype = A  && ctrl
trigger2 = stateno = 400 && MoveContact
trigger3 = stateno = 415 && MoveContact
;---------------------------------------------------------------------------
;Jumping Hard Punch + Down (Screen Bouncy Buzszsaw)
[State -1, Jumping Hard Punch + Down]
type = ChangeState
value = 411
triggerall = command = "down_z"
trigger1 = statetype = A && ctrl
trigger2 = stateno = 400 && MoveContact
trigger3 = stateno = 415 && MoveContact
trigger4 = stateno = 405 && MoveContact
trigger5 = stateno = 420 && MoveContact
;---------------------------------------------------------------------------
;Jumping Hard Punch
[State -1, Jumping Hard Punch]
type = ChangeState
value = 410
triggerall = command = "z" && command != "holddown"
trigger1 = statetype = A  && ctrl
trigger2 = stateno = 400 && MoveContact 
trigger3 = stateno = 415 && MoveContact
trigger4 = stateno = 405 && MoveContact 
trigger5 = stateno = 420 && MoveContact 
;---------------------------------------------------------------------------
;Jumping Light Kick
[State -1, Jumping Light Kick]
type = ChangeState
value = 415
triggerall = command = "a" && command != "holddown"
trigger1 = statetype = A  && ctrl
trigger2 = stateno = 400 && MoveContact
;---------------------------------------------------------------------------
;Jumping Medium Kick
[State -1, Jumping Medium Kick]
type = ChangeState
value = 420
triggerall = command = "b" && command != "holddown"
trigger1 = statetype = A  && ctrl
trigger2 = stateno = 400 && MoveContact
trigger3 = stateno = 415 && MoveContact
trigger4 = stateno = 405 && MoveContact
;---------------------------------------------------------------------------
;Jumping Hard Kick
[State -1, Jumping Hard Kick]
type = ChangeState
value = 425
triggerall = command = "c" && command != "holddown"
trigger1 = statetype = A && ctrl
trigger2 = stateno = 400 && MoveContact
trigger3 = stateno = 415 && MoveContact
trigger4 = stateno = 405 && MoveContact
trigger5 = stateno = 420 && MoveContact
trigger6 = stateno = 421 && MoveContact
;---------------------------------------------------------------------------
;Super Jump
[State -1, Super Jump]
type = ChangeState
value = 90
triggerall = command = "Super_Jump" ;&& ctrl
trigger1 = StateType = S
trigger1= ctrl
;---------------------------------------------------------------------------
;Recovery Roll 
[State -1, RR]
type = VarSet
triggerall = command = "roll" && alive = 1
trigger1 = stateno = 5050 || stateno = 5071
v = 10
value = 1

;Recovery Roll 
[State -1, Roll]
type = ChangeState
value = 430
triggerall = Var(10) = 1
trigger1 = Pos Y >= 0 && Vel Y > 0

;---------------------------------------------------------------------------
;------------------------ Lie Down Recovery Roll ---------------------------
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
; Lie Down Forward Recovery Roll

[State -1]
type = ChangeState
value = 832
triggerall = Var(59) != 2
triggerall = command = "holdfwd"
triggerall = time = 1
triggerall = life > 0
trigger1 = stateno = 5120
trigger1 = alive = 1

;---------------------------------------------------------------------------
; Lie Down Backward Recovery Roll

[State -1]
type = ChangeState
value = 855
triggerall = Var(59) != 2
triggerall = command = "holdback"
triggerall = time = 1
triggerall = life > 0
trigger1 = stateno = 5120
trigger1 = alive = 1


